# Инструменты разработки

## uv

=== "macOS and Linux"
    ``` sh
    curl -LsSf https://astral.sh/uv/install.sh | sh
    ```
=== "Windows"
    ``` sh
    powershell -ExecutionPolicy ByPass -c "irm https://astral.sh/uv/install.ps1 | iex"
    ```
